package hermes;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Insets;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JWindow;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

/**
 * Modified by fhogenboom.
 */
public class SplashScreen extends JWindow
{

    private JProgressBar progress;

    public SplashScreen(ImageIcon icon)
    {
        UIManager.put("ProgressBar.background", new Color(1.0f, 1.0f, 1.0f, 0.0f));
        UIManager.put("ProgressBar.foreground", new Color(0.68f, 0.0f, 0.0f, 1.0f));
        UIManager.put("ProgressBar.selectionBackground", new Color(0.0f, 0.0f, 0.0f, 1.0f));
        UIManager.put("ProgressBar.selectionForeground", new Color(1.0f, 1.0f, 1.0f, 1.0f));
        progress = new JProgressBar();
        progress.setBorderPainted(false);
        progress.setOpaque(false);
        progress.setPreferredSize(new Dimension(600, 25));
        ImagePanel panel = new ImagePanel(icon.getImage());
        panel.setLayout(new BorderLayout());
        panel.add(progress, BorderLayout.SOUTH);
        panel.setBorder(BorderFactory.createEmptyBorder(50, 100, 50, 100));
        this.getContentPane().add(panel);
        this.pack();
        this.setVisible(true);
    }
    
    public void setProgressMax(int max)
    {
        progress.setMaximum(max);
    }
    
    public void setProgress(int prog)
    {
        final int p = prog;
        SwingUtilities.invokeLater(new Runnable()
        {
            @Override
            public void run()
            {
                progress.setValue(p);
            }
        });
    }
    
    public void setProgress(String msg, int prog)
    {
        final int p = prog;
        final String m = msg;
        SwingUtilities.invokeLater(new Runnable()
        {
            @Override
            public void run()
            {
                progress.setValue(p);
                setMessage(m);
            }
        });
    }
    
    public void setScreenVisible(boolean vis)
    {
        final boolean v = vis;
        SwingUtilities.invokeLater(new Runnable()
        {
            @Override
            public void run()
            {
                setVisible(v);
            }
        });
    }
    
    private void setMessage(String msg)
    {
        if (msg == null)
        {
            msg = "";
            progress.setStringPainted(false);
        }
        else
        {
            progress.setStringPainted(true);
        }
        progress.setString(msg);
    }
    
    private class ImagePanel extends JPanel
    {
        
        private Image img;
        
        public ImagePanel(Image img)
        {
            this.img = img;
            Dimension size = new Dimension(img.getWidth(null), img.getHeight(null));
            setPreferredSize(size);
            setMinimumSize(size);
            setMaximumSize(size);
            setSize(size);
            setLayout(null);
        }
        
        @Override
        public void paintComponent(Graphics g)
        {
            g.drawImage(img, 0, 0, null);
        }
        
    }
    
}
